@@ -19,19 +19,18 @@ use crate::node::{
     core::{Comm, ConnectionEvent, SendStatus},
     dkg::SectionAuthUtils,
     ed25519,
-    messages::{NodeMsgAuthorityUtils, WireMsgUtils},
+    messages::WireMsgUtils,
     network_knowledge::NetworkKnowledge,
     Error, NodeInfo, Result, MIN_ADULT_AGE,
 };
-use crate::types::{log_markers::LogMarker, prefix_map::NetworkPrefixMap, Peer, UnnamedPeer};
+use crate::types::{log_markers::LogMarker, prefix_map::NetworkPrefixMap, Peer};
 
 use backoff::{backoff::Backoff, ExponentialBackoff};
 use bls::PublicKey as BlsPublicKey;
 use futures::future;
 use resource_proof::ResourceProof;
-use std::collections::BTreeMap;
-use tokio::time::sleep;
-use tokio::{sync::mpsc, time::Duration};
+use std::{collections::BTreeMap, net::SocketAddr};
+use tokio::{sync::mpsc, time::sleep, time::Duration};
 use tracing::Instrument;
 use xor_name::Prefix;
 
@@ -47,7 +46,7 @@ pub(crate) async fn join_network(
     node: NodeInfo,
     comm: &Comm,
     incoming_conns: &mut mpsc::Receiver<ConnectionEvent>,
-    bootstrap_peer: UnnamedPeer,
+    bootstrap_addr: SocketAddr,
     genesis_key: BlsPublicKey,
 ) -> Result<(NodeInfo, NetworkKnowledge)> {
     let (send_tx, send_rx) = mpsc::channel(1);
@@ -59,7 +58,7 @@ pub(crate) async fn join_network(
 
     let state = Join::new(node, send_tx, incoming_conns, prefix_map);
 
-    future::join(state.run(bootstrap_peer), send_messages(send_rx, comm))
+    future::join(state.run(bootstrap_addr), send_messages(send_rx, comm))
         .instrument(span)
         .await
         .0
@@ -115,14 +114,13 @@ impl<'a> Join<'a> {
     // - `ResourceChallenge`: carry out resource proof calculation.
     // - `Approval`: returns the initial `Section` value to use by this node,
     //    completing the bootstrap.
-    async fn run(self, bootstrap_peer: UnnamedPeer) -> Result<(NodeInfo, NetworkKnowledge)> {
+    async fn run(self, bootstrap_addr: SocketAddr) -> Result<(NodeInfo, NetworkKnowledge)> {
         // Use our XorName as we do not know their name or section key yet.
-        let bootstrap_peer = bootstrap_peer.named(self.node.name());
+        let bootstrap_peer = Peer::new(self.node.name(), bootstrap_addr);
         let genesis_key = self.prefix_map.genesis_key();
 
         let (target_section_key, recipients) =
             if let Ok(sap) = self.prefix_map.section_by_name(&bootstrap_peer.name()) {
-                sap.merge_connections([&bootstrap_peer]).await;
                 (sap.section_key(), sap.elders_vec())
             } else {
                 (genesis_key, vec![bootstrap_peer])
@@ -201,9 +199,6 @@ impl<'a> Join<'a> {
                     // Building our network knowledge instance will validate SAP and section chain.
                     let section_auth = section_auth.into_authed_state();
 
-                    // Include the sender's connection in our initial knowledge
-                    section_auth.merge_connections([&sender]).await;
-
                     let network_knowledge = NetworkKnowledge::new(
                         genesis_key,
                         section_chain,
@@ -414,9 +409,6 @@ impl<'a> Join<'a> {
                         aggregated: None,
                     };
 
-                    section_auth
-                        .merge_connections(recipients.iter().chain([&sender]))
-                        .await;
                     let new_recipients = section_auth.elders_vec();
                     self.send_join_requests(join_request, &new_recipients, section_key, true)
                         .await?;
@@ -473,9 +465,6 @@ impl<'a> Join<'a> {
                         aggregated: None,
                     };
 
-                    section_auth
-                        .merge_connections(recipients.iter().chain([&sender]))
-                        .await;
                     self.send_join_requests(join_request, &new_recipients, section_key, true)
                         .await?;
                 }
@@ -556,43 +545,36 @@ impl<'a> Join<'a> {
         while let Some(event) = self.recv_rx.recv().await {
             // We are interested only in `JoinResponse` type of messages
             let (join_response, sender) = match event {
-                ConnectionEvent::Received((sender, bytes)) => match WireMsg::from(bytes) {
-                    Ok(wire_msg) => match wire_msg.msg_kind() {
-                        MsgKind::ServiceMsg(_) => continue,
-                        MsgKind::NodeBlsShareAuthMsg(_) => {
+                ConnectionEvent::Received {
+                    sender, wire_msg, ..
+                } => match wire_msg.msg_kind() {
+                    MsgKind::ServiceMsg(_) => continue,
+                    MsgKind::NodeBlsShareAuthMsg(_) => {
+                        trace!(
+                            "Bootstrap message discarded: sender: {:?} wire_msg: {:?}",
+                            sender,
+                            wire_msg
+                        );
+                        continue;
+                    }
+                    MsgKind::NodeAuthMsg(NodeAuth { .. }) => match wire_msg.into_msg() {
+                        Ok(MsgType::System {
+                            msg: SystemMsg::JoinResponse(resp),
+                            ..
+                        }) => (*resp, sender),
+                        Ok(MsgType::Service { msg_id, .. } | MsgType::System { msg_id, .. }) => {
                             trace!(
-                                "Bootstrap message discarded: sender: {:?} wire_msg: {:?}",
+                                "Bootstrap message discarded: sender: {:?} msg_id: {:?}",
                                 sender,
-                                wire_msg
+                                msg_id
                             );
                             continue;
                         }
-                        MsgKind::NodeAuthMsg(NodeAuth { .. }) => match wire_msg.into_msg() {
-                            Ok(MsgType::System {
-                                msg: SystemMsg::JoinResponse(resp),
-                                msg_authority,
-                                ..
-                            }) => (*resp, sender.named(msg_authority.src_location().name())),
-                            Ok(
-                                MsgType::Service { msg_id, .. } | MsgType::System { msg_id, .. },
-                            ) => {
-                                trace!(
-                                    "Bootstrap message discarded: sender: {:?} msg_id: {:?}",
-                                    sender,
-                                    msg_id
-                                );
-                                continue;
-                            }
-                            Err(err) => {
-                                debug!("Failed to deserialize message payload: {:?}", err);
-                                continue;
-                            }
-                        },
+                        Err(err) => {
+                            debug!("Failed to deserialize message payload: {:?}", err);
+                            continue;
+                        }
                     },
-                    Err(err) => {
-                        debug!("Failed to deserialize message: {:?}", err);
-                        continue;
-                    }
                 },
             };
 
@@ -680,12 +662,7 @@ mod tests {
         );
 
         // Create the bootstrap task, but don't run it yet.
-        let bootstrap = async move {
-            state
-                .run(UnnamedPeer::addressed(bootstrap_addr))
-                .await
-                .map_err(Error::from)
-        };
+        let bootstrap = async move { state.run(bootstrap_addr).await.map_err(Error::from) };
 
         // Create the task that executes the body of the test, but don't run it either.
         let others = async {
@@ -788,7 +765,7 @@ mod tests {
             NetworkPrefixMap::new(genesis_key),
         );
 
-        let bootstrap_task = state.run(UnnamedPeer::addressed(bootstrap_node.addr));
+        let bootstrap_task = state.run(bootstrap_node.addr);
         let test_task = async move {
             // Receive JoinRequest
             let (wire_msg, recipients) = send_rx
@@ -891,7 +868,7 @@ mod tests {
             NetworkPrefixMap::new(section_key),
         );
 
-        let bootstrap_task = state.run(UnnamedPeer::addressed(bootstrap_node.addr));
+        let bootstrap_task = state.run(bootstrap_node.addr);
         let test_task = async {
             let (wire_msg, _) = send_rx
                 .recv()
@@ -979,7 +956,7 @@ mod tests {
             NetworkPrefixMap::new(section_key),
         );
 
-        let bootstrap_task = state.run(UnnamedPeer::addressed(bootstrap_node.addr));
+        let bootstrap_task = state.run(bootstrap_node.addr);
         let test_task = async {
             let (wire_msg, _) = send_rx
                 .recv()
@@ -1138,10 +1115,13 @@ mod tests {
 
         debug!("wire msg built");
 
-        recv_tx.try_send(ConnectionEvent::Received((
-            UnnamedPeer::addressed(bootstrap_node.addr),
-            wire_msg.serialize()?,
-        )))?;
+        let original_bytes = wire_msg.serialize()?;
+
+        recv_tx.try_send(ConnectionEvent::Received {
+            sender: bootstrap_node.peer(),
+            wire_msg,
+            original_bytes,
+        })?;
 
         Ok(())
     }
