@@ -98,30 +98,29 @@ pub(crate) struct Node {
     pub(crate) info: Arc<RwLock<NodeInfo>>,
 
     pub(crate) comm: Comm,
-    pub(crate) section_keys_provider: SectionKeysProvider,
 
     pub(super) data_storage: DataStorage, // Adult only before cache
 
     resource_proof: ResourceProof,
-
+    // Network resources
+    pub(crate) section_keys_provider: SectionKeysProvider,
     network_knowledge: NetworkKnowledge,
-
+    // Signature aggregators
     message_aggregator: SignatureAggregator,
-
     proposal_aggregator: SignatureAggregator,
+    // DKG/Split/Churn modules
     split_barrier: Arc<RwLock<SplitBarrier>>,
     dkg_sessions: Arc<RwLock<HashMap<DkgSessionId, DkgSessionInfo>>>,
     dkg_voter: DkgVoter,
-
     relocate_state: Arc<RwLock<Option<Box<JoiningAsRelocated>>>>,
-
-    joins_allowed: Arc<RwLock<bool>>,        // Elder only
-    current_joins_semaphore: Arc<Semaphore>, // Elder only
-
-    capacity: Capacity,                                       // Elder only
-    liveness: Liveness,                                       // Elder only
-    pending_data_queries: Arc<Cache<OperationId, Vec<Peer>>>, // Elder only
-
+    // ======================== Elder only ========================
+    joins_allowed: Arc<RwLock<bool>>,
+    current_joins_semaphore: Arc<Semaphore>,
+    // Trackers
+    capacity: Capacity,
+    liveness: Liveness,
+    pending_data_queries: Arc<Cache<OperationId, Vec<Peer>>>,
+    // Caches
     ae_backoff_cache: AeBackoffCache,
 }
 
